==> postfile-1.0.0.tar.gz: postfile/src/Form/Settings.php <==
<?php

namespace Drupal\postfile\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StreamWrapper\StreamWrapperInterface;
use Drupal\Core\StreamWrapper\StreamWrapperManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Settings Form class.
 */
class Settings extends ConfigFormBase {

  /**
   * The stream wrapper manager.
   *
   * @var \Drupal\Core\StreamWrapper\StreamWrapperManagerInterface
   */
  protected StreamWrapperManagerInterface $streamWrapperManager;

  /**
   * Constructs a FileSystemForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Config\TypedConfigManagerInterface $typedConfigManager
   *   The typed config manager.
   * @param \Drupal\Core\StreamWrapper\StreamWrapperManagerInterface $stream_wrapper_manager
   *   The stream wrapper manager.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    TypedConfigManagerInterface $typedConfigManager,
    StreamWrapperManagerInterface $stream_wrapper_manager
  ) {
    parent::__construct($config_factory, $typedConfigManager);
    $this->streamWrapperManager = $stream_wrapper_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('config.typed'),
      $container->get('stream_wrapper_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'postfile_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'postfile.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $settings = $this->config('postfile.settings');

    $form['filesystem'] = [
      '#type' => 'radios',
      '#title' => $this->t('File System'),
      '#default_value' => $settings->get('filesystem'),
      '#options' => $this->streamWrapperManager->getDescriptions(StreamWrapperInterface::WRITE_VISIBLE),
    ];

    $form['directory'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Directory'),
      '#description' => $this->t('The directory within the filesystem to store the file. Do not include the beginning or ending slashes.'),
      '#default_value' => $settings->get('directory'),
    ];

    $form['exists_action'] = [
      '#type' => 'radios',
      '#title' => $this->t('File Exists Action'),
      '#description' => $this->t('If the file exists, which action should be taken.'),
      '#default_value' => $settings->get('exists_action'),
      '#options' => [
        FileSystemInterface::EXISTS_RENAME => $this->t('Rename file'),
        FileSystemInterface::EXISTS_REPLACE => $this->t('Replace file'),
        FileSystemInterface::EXISTS_ERROR => $this->t('Throw error'),
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();

    $this->config('postfile.settings')
      ->set('filesystem', $values['filesystem'])
      ->set('directory', $values['directory'])
      ->set('exists_action', $values['exists_action'])
      ->save();

    parent::submitForm($form, $form_state);
  }

}

==> postfile-1.0.1.tar.gz: postfile/src/Form/Settings.php <==
<?php

namespace Drupal\postfile\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\File\FileExists;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StreamWrapper\StreamWrapperInterface;
use Drupal\Core\StreamWrapper\StreamWrapperManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Settings Form class.
 */
class Settings extends ConfigFormBase {

  /**
   * The stream wrapper manager.
   *
   * @var \Drupal\Core\StreamWrapper\StreamWrapperManagerInterface
   */
  protected StreamWrapperManagerInterface $streamWrapperManager;

  /**
   * Constructs a FileSystemForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Config\TypedConfigManagerInterface $typedConfigManager
   *   The typed config manager.
   * @param \Drupal\Core\StreamWrapper\StreamWrapperManagerInterface $stream_wrapper_manager
   *   The stream wrapper manager.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    TypedConfigManagerInterface $typedConfigManager,
    StreamWrapperManagerInterface $stream_wrapper_manager,
  ) {
    parent::__construct($config_factory, $typedConfigManager);
    $this->streamWrapperManager = $stream_wrapper_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('config.typed'),
      $container->get('stream_wrapper_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'postfile_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'postfile.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $settings = $this->config('postfile.settings');

    $form['filesystem'] = [
      '#type' => 'radios',
      '#title' => $this->t('File System'),
      '#default_value' => $settings->get('filesystem'),
      '#options' => $this->streamWrapperManager->getDescriptions(StreamWrapperInterface::WRITE_VISIBLE),
    ];

    $form['directory'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Directory'),
      '#description' => $this->t('The directory within the filesystem to store the file. Do not include the beginning or ending slashes.'),
      '#default_value' => $settings->get('directory'),
    ];

    $form['exists_action'] = [
      '#type' => 'radios',
      '#title' => $this->t('File Exists Action'),
      '#description' => $this->t('If the file exists, which action should be taken.'),
      '#default_value' => $settings->get('exists_action'),
      '#options' => [
        FileExists::Rename => $this->t('Rename file'),
        FileExists::Replace => $this->t('Replace file'),
        FileExists::Error => $this->t('Throw error'),
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();

    $this->config('postfile.settings')
      ->set('filesystem', $values['filesystem'])
      ->set('directory', $values['directory'])
      ->set('exists_action', $values['exists_action'])
      ->save();

    parent::submitForm($form, $form_state);
  }

}
